@@ -22,6 +22,6 @@ class AirflowLocal(Asset):
 
         :param destination: directory location for infrastructure setup generation
         """
-        log_if_verbose("Preparing action_required.md file", self.verbose)
+        log_if_verbose("Preparing Apache Airflow local environment", self.verbose)
 
         copy_tree(f"extra_assets/{self.name}", f"{destination}/{self.name}")
